% Empirical illustration
%
% Last update on Mar 2019 to include estimations with all moment

addmypath;

%% Preliminary analysis
data_temp = csvread('data/raw_data_DAX30.csv',1,1); % 2010.01.01 - 2016.05.31
N = 10;
data = data_temp(:,1:N); 
colname = {'SAP','SIE','BAYN','ALV','BAS','DAI','DTE','BMW','DPW','CON'};

res = NaN(length(data)-1,N);
for i = 1:N
    res(:,i) = diff(log(data(:,i)));
end
res = res*100;
res( ~any(res,2), : ) = [];

stat = NaN(4,N);
for i = 1:N
    stat(1,i) = mean(res(:,i));
    stat(2,i) = std(res(:,i));
    stat(3,i) = skewness(res(:,i));
    stat(4,i) = kurtosis(res(:,i));
end
T = length(res);

param = NaN(8,N);
resid = NaN(T,N);
uresid = NaN(T,N);
Likelihood = NaN(2,N);
for i = 1:N 
   [~,param_temp,~,~,resid_temp,~,Likelihood(:,i)] = fitARMAGARCH(res(:,i),[1 0 1 1 1],'SKEWT');
   param(:,i) = param_temp';
   resid(:,i) = resid_temp;
   uresid(:,i) = tiedrank(resid_temp)/(T+1);
end

% Sample dependence
m = zeros(N,N);
n = zeros(N,N);
l = zeros(N,N);

for i = 1:(N-1)
    for j = i+1:N        
        m(i,j) = sum(mSrho( uresid(:,i), uresid(:,j) ) )/T;
        n(i,j) = ( sum( mQdep( uresid(:,i), uresid(:,j), 0.99 ) ) / T + sum( mQdep( uresid(:,i), uresid(:,j), 0.01 ) ) / T ) /2;
    end
end

for j = 1:(N-1)
    for i = j+1:N
        l(i,j) = sum( mQdep( uresid(:,i), uresid(:,j), 0.9 ) ) / T - sum( mQdep( uresid(:,i), uresid(:,j), 0.1 ) ) / T;
    end
end
quantile_matrix = l+n;

%%  SMM estimation & model selections across models
% compute the estimators of copula parameters and corresponding selection
% criteria
S = 25;
dpd = 'Equidep_theta';
Jstat = zeros(30,1);
pval = zeros(30,1);
crit = zeros(30,1);
thetahat = NaN(30,3);
msc = NaN(30,3);
seed = 1;
other2 = [S*T N 2*seed]; % estimation use whole sample

for i = 1:30
    model = i;
    disp(strcat('Model:',num2str(i)))
    settings;
    
    [thetahat(i,1:length(theta_guess)),~] = fminsearchbnd('objfunc_SMM',theta_guess,LB,UB,options,simfunc_est,other2,dpd,momfunc,uresid,W,q);
    [~,ghat] = objfunc_SMM(thetahat(i,1:length(theta_guess)),simfunc_est,other2,dpd,momfunc,uresid,W,q);
    % J test
    Jstat(i,1) = min(T,S*T) * ghat' * W * ghat;
    
    % Bootstrap
    B = 1000; % # of bootstrapping
    alpha = 0.95;
    sigma0hat = sigma0(uresid,momfunc,dim,0,q);
    [G0hat,~] = G0(thetahat(i,1:length(theta_guess)),uresid,simfunc_est,other2,dpd,momfunc,W,dim,q);
    R0 = eye(size(sigma0hat)) -( (sigma0hat^(-1/2) * G0hat) / (G0hat' * W * G0hat) )* (G0hat' * W * sigma0hat ^ (1/2)); 
    A0 = (W^(1/2)) * (sigma0hat^(1/2)) * R0;
    [mysize,~] = size(A0);
    rand('state',100*seed);
    randn('state',100*seed);
    u = randn(mysize,B);
    Jboot = zeros(B,1);
    for ii = 1:B
        Jboot(ii,1) = u(:,ii)' * (A0') * A0 * u(:,ii);
    end
    pval(i,1) = sum(Jstat(i,1) < Jboot) / B;
    sortJboot = sort(Jboot);
    crit(i,1) = sortJboot(floor(alpha*B));
    
    if strcmp(momfunc,'momfunc_Equidep_lower')
        msc(i,:) = [(Jstat(i,1) - (length(q)-sum(~isnan(thetahat(i,:))))*2)...
                (Jstat(i,1) - (length(q)-sum(~isnan(thetahat(i,:))))*log(T))...
                (Jstat(i,1) - (length(q)-sum(~isnan(thetahat(i,:))))*2.01*log(log(T)))];
    else    
        msc(i,:) = [(Jstat(i,1) - (length(q)+1-sum(~isnan(thetahat(i,:))))*2)...
                (Jstat(i,1) - (length(q)+1-sum(~isnan(thetahat(i,:))))*log(T))...
                (Jstat(i,1) - (length(q)+1-sum(~isnan(thetahat(i,:))))*2.01*log(log(T)))];  
    end  
end

%%  SMM estimation settings
EstimationWindowSize = 1000;
TestWindowStart = EstimationWindowSize + 1;
TestWindow = TestWindowStart : T;
TestWindowSize = T - EstimationWindowSize;

pVaR = [0.05 0.01];
MCsize = 100000; % random draws to determine the distribution under estimated model
S = 25;
dpd = 'Equidep_theta';
%%  VaR forecasting and backtesting
model = 25; % possible model 25 - 30
settings;
% Estimation of copula and dynamic parameters in margins 
VaR = NaN(TestWindowSize,length(pVaR)); % VaR forecasts
VaR  = NaN(TestWindowSize, length(pVaR));
ht_one = NaN(TestWindowSize, N);
thetahat = NaN(TestWindowSize,length(theta_guess));
for t = TestWindow
     i = t - TestWindowStart + 1;
     seed = i;
     other2 = [S*EstimationWindowSize N 2*seed];
     disp(strcat('Test Date',num2str(i)))
     EstimationWindow = t - EstimationWindowSize: t-1;     
     res_est = res(EstimationWindow,:);     % use return series, not uniform number yet
     param_est = NaN(8,N);
     resid_est = NaN(EstimationWindowSize,N);
     uresid_est = NaN(EstimationWindowSize,N);
     ht_est = NaN(EstimationWindowSize,N);
     for dim = 1:N 
       [~,param_temp,~,~,resid_temp,ht_temp,~] = fitARMAGARCH(res_est(:,dim),[1 0 1 1 1],'SKEWT');
       param_est(:,dim) = param_temp';
       resid_est(:,dim) = resid_temp;
       ht_est(:,dim) = ht_temp;
       uresid_est(:,dim) = tiedrank(resid_temp)/(EstimationWindowSize+1); % non-parametric transformation
       ht_one(i,dim) = param_est(3,dim) + ...
                                param_est(4,dim) * ht_est(EstimationWindowSize,dim) * resid_est(EstimationWindowSize,dim)^2 + ...
                                param_est(5,dim) * ht_est(EstimationWindowSize,dim) * resid_est(EstimationWindowSize,dim)^2 * (resid_est(EstimationWindowSize,dim)<=0) + ...
                                param_est(6,dim) * ht_est(EstimationWindowSize,dim); % volatility forecast
     end

     [thetahat(i,:),~] = fminsearchbnd('objfunc_SMM',theta_guess,LB,UB,options,simfunc_est,other2,dpd,momfunc,uresid_est,W,q);
 
     data_uresid_sim = feval(simfunc_est,thetahat(i,:),[MCsize N 2*seed],dpd);
     data_resid_sim = NaN(MCsize,N);
     for d = 1:N
         data_resid_sim(:,d) = empirical_cdfi(data_uresid_sim(:,d),resid_est(:,d)); 
     end
     
     data_sim = NaN(MCsize,N);
     VaR_sim = NaN(MCsize,1);
     for ii = 1:MCsize
         for dd = 1:N
             data_sim(ii,dd) = param_est(1,dd) + ...
                                         param_est(2,dd) * res_est(EstimationWindowSize,dd) + ...
                                         sqrt(ht_one(i,dd)) * data_resid_sim(ii,dd);
         end
         VaR_sim(ii,1) = log(1+mean((exp(data_sim(ii,:))-1),2));
     end
     VaR(i,:) = quantile(VaR_sim,pVaR);
end
pf_true = log(1+mean((exp(res)-1),2));
I = [VaR(:,1) > pf_true(TestWindow) VaR(:,2) > pf_true(TestWindow)];
v = sum(I);
coverage = v./TestWindowSize;

% Backtesting tests
k_stat = [fPFtest(I(:,1), pVaR(1)) fPFtest(I(:,2), pVaR(2))];
cav_stat = [fDynamicQuantileTest(I(:,1), pVaR(1),1) fDynamicQuantileTest(I(:,2), pVaR(2),1)];
pval_k = [1 - chi2cdf(k_stat(1),1) 1 - chi2cdf(k_stat(2),1)];
pval_cav = [1 - chi2cdf(cav_stat(1),2) 1 - chi2cdf(cav_stat(2),2)];
[~,~,ch_stat(1),~,~,pval_ch(1)] = christof(I(:,1), pVaR(1));
[~,~,ch_stat(2),~,~,pval_ch(2)] = christof(I(:,2), pVaR(2));
% Save workspace
save(strcat('Workspace_empirical_model_',num2str(model),'.mat'));