% This file is to generate results of the simultaneous selection frequencies of all combinations of models and moments based on MSC
% the result includes the complete selection frequencies of all combinations of true \& candidate model \& moments w.r.t T, N, with pre-determined choice of criterions.
% Last edit on April 2019
clear
clc

root = '~/Dropbox/MATLAB';
cd(root)
addpath(fullfile(root, 'utils')); % add some functions like matrix2latex.m

rowLabels = repmat({'n-n','t-t','skewn-n','skewt-t'},1,5);
columnLabels = repmat({'n-n','t-t','skewn-n','skewt-t'},1,3);    

J_all = NaN(200,20);
J = NaN(200,4);
cri = {'hqic'};
N = 10;
model_candidate = {'simfunc_gaussian','simfunc_tt','simfunc_skewnn','simfunc_skewtt'};
T_dim = [500 1000 2000];
quantile_set = {'left0','left','tail','central','all'};
dpd_path = 'Equidep_theta';

output_horizon = [];
for idx_T = 1:3
    T = T_dim(idx_T);
    output_vertical = [];
    for idx_true = 1:4
        model_true = model_candidate{idx_true};
        for idx_q = 1:length(quantile_set)
            cd(fullfile(root, strcat('mat/niid_', dpd_path,'_',quantile_set{idx_q})));
            for index_model=1:length(model_candidate)
                if strcmp(model_true, model_candidate{index_model})
                    type = 'Size_niid_';
                else
                    type = 'Power_niid_';
                end
                load(strcat(type,model_true,'_est_by_',model_candidate{index_model},'_T',num2str(T),'_N',num2str(N),'_R200_',dpd_path,'.mat'));                            
                J(:,index_model) = Jstat;
            end
             J_all(:,(1+(idx_q-1)*4):(4+(idx_q-1)*4)) = J;
        end    
        msc = zeros(200,20);
        if strcmp(cri,'aic')
            kappa = 2;
        elseif strcmp(cri,'bic')
            kappa = log(T);
        elseif strcmp(cri,'hqic')
            kappa = 2.01*log(log(T));
        else
        disp('wrong criterion input')
        end
        msc(:,1) = J_all(:,1) - (4-1)*kappa;
        msc(:,2) = J_all(:,2) - (4-2)*kappa;
        msc(:,3) = J_all(:,3) - (4-2)*kappa;
        msc(:,4) = J_all(:,4) - (4-3)*kappa;
        msc(:,5) = J_all(:,5) - (5-1)*kappa;
        msc(:,6) = J_all(:,6) - (5-2)*kappa;
        msc(:,7) = J_all(:,7) - (5-2)*kappa;
        msc(:,8) = J_all(:,8) - (5-3)*kappa;                       
        msc(:,9) = J_all(:,9) - (5-1)*kappa;
        msc(:,10) = J_all(:,10) - (5-2)*kappa;
        msc(:,11) = J_all(:,11) - (5-2)*kappa;
        msc(:,12) = J_all(:,12) - (5-3)*kappa;  
        msc(:,13) = J_all(:,13) - (5-1)*kappa;
        msc(:,14) = J_all(:,14) - (5-2)*kappa;
        msc(:,15) = J_all(:,15) - (5-2)*kappa;
        msc(:,16) = J_all(:,16) - (5-3)*kappa;  
        msc(:,17) = J_all(:,17) - (9-1)*kappa;
        msc(:,18) = J_all(:,18) - (9-2)*kappa;
        msc(:,19) = J_all(:,19) - (9-2)*kappa;
        msc(:,20) = J_all(:,20) - (9-3)*kappa;
  
        min_msc = zeros(200,1);
        for i = 1:200
            min_msc(i,1) = min(msc(i,:));
        end  
        output_cell(:,idx_true) = [mean(min_msc == msc(:,1));
                                                mean(min_msc == msc(:,2));
                                                mean(min_msc == msc(:,3));
                                                mean(min_msc == msc(:,4));
                                                mean(min_msc == msc(:,5));
                                                mean(min_msc == msc(:,6)); 
                                                mean(min_msc == msc(:,7)); 
                                                mean(min_msc == msc(:,8));
                                                mean(min_msc == msc(:,9)); 
                                                mean(min_msc == msc(:,10)); 
                                                mean(min_msc == msc(:,11)); 
                                                mean(min_msc == msc(:,12));
                                                mean(min_msc == msc(:,13)); 
                                                mean(min_msc == msc(:,14)); 
                                                mean(min_msc == msc(:,15)); 
                                                mean(min_msc == msc(:,16));
                                                mean(min_msc == msc(:,17)); 
                                                mean(min_msc == msc(:,18)); 
                                                mean(min_msc == msc(:,19)); 
                                                mean(min_msc == msc(:,20))];                                    
                                            
   end
   output_horizon = [output_horizon output_cell];    
end  
       
cd(root)
matrix2latex(output_horizon,strcat('prob_msc_all_N', num2str(N),'_fixed_criterion_', cri{1},'.tex'),'rowLabels',rowLabels,'columnLabels',columnLabels,'format','%.3f');